package org.jeecg.modules.hotelgoodssku.controller;

import java.util.*;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.hotelgoods.entity.HotelGoods;
import org.jeecg.modules.hotelgoods.service.IHotelGoodsService;
import org.jeecg.modules.hotelgoodssku.entity.HotelGoodsSku;
import org.jeecg.modules.hotelgoodssku.service.IHotelGoodsSkuService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: hotel_goods_sku
 * @Author: jeecg-boot
 * @Date:   2024-09-13
 * @Version: V1.0
 */
@Api(tags="hotel_goods_sku")
@RestController
@RequestMapping("/hotelgoodssku/hotelGoodsSku")
@Slf4j
public class HotelGoodsSkuController extends JeecgController<HotelGoodsSku, IHotelGoodsSkuService> {
	@Autowired
	private IHotelGoodsSkuService hotelGoodsSkuService;
	@Resource
	private IHotelGoodsService hotelGoodsService;

	/**
	 * 分页列表查询
	 *
	 * @param hotelGoodsSku
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "hotel_goods_sku-分页列表查询")
	@ApiOperation(value="hotel_goods_sku-分页列表查询", notes="hotel_goods_sku-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<HotelGoodsSku>> queryPageList(HotelGoodsSku hotelGoodsSku,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<HotelGoodsSku> queryWrapper = QueryGenerator.initQueryWrapper(hotelGoodsSku, req.getParameterMap());
		Page<HotelGoodsSku> page = new Page<HotelGoodsSku>(pageNo, pageSize);
		IPage<HotelGoodsSku> pageList = hotelGoodsSkuService.page(page, queryWrapper);
		return Result.OK(pageList);
	}



	/**
	 *   添加
	 *
	 * @param hotelGoodsSku
	 * @return
	 */
	@AutoLog(value = "hotel_goods_sku-添加")
	@ApiOperation(value="hotel_goods_sku-添加", notes="hotel_goods_sku-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody HotelGoodsSku hotelGoodsSku) {
		HotelGoodsSku hotelGoodsSku1 = hotelGoodsSkuService.lambdaQuery()
				.eq(HotelGoodsSku::getDelFlag, 0)
				.eq(HotelGoodsSku::getGoodsId, hotelGoodsSku.getGoodsId())
				.eq(HotelGoodsSku::getColour, hotelGoodsSku.getColour())
				.eq(HotelGoodsSku::getTitle, hotelGoodsSku.getTitle())
				.one();
		if(hotelGoodsSku1 != null){
			throw new JeecgBootException("该规格已存在，请勿重复添加");
		}
		hotelGoodsSkuService.save(hotelGoodsSku);
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param hotelGoodsSku
	 * @return
	 */
	@AutoLog(value = "hotel_goods_sku-编辑")
	@ApiOperation(value="hotel_goods_sku-编辑", notes="hotel_goods_sku-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody HotelGoodsSku hotelGoodsSku) {
		HotelGoodsSku hotelGoodsSku1 = hotelGoodsSkuService.lambdaQuery()
				.eq(HotelGoodsSku::getDelFlag, 0)
				.eq(HotelGoodsSku::getGoodsId, hotelGoodsSku.getGoodsId())
				.eq(HotelGoodsSku::getColour, hotelGoodsSku.getColour())
				.eq(HotelGoodsSku::getTitle, hotelGoodsSku.getTitle())
				.one();
		if(hotelGoodsSku1 != null){
			throw new JeecgBootException("该规格已存在，请勿重复添加");
		}
		hotelGoodsSkuService.updateById(hotelGoodsSku);
		return Result.OK("编辑成功!");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "hotel_goods_sku-通过id删除")
	@ApiOperation(value="hotel_goods_sku-通过id删除", notes="hotel_goods_sku-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		hotelGoodsSkuService.removeById(id);
		return Result.OK("删除成功!");
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "hotel_goods_sku-批量删除")
	@ApiOperation(value="hotel_goods_sku-批量删除", notes="hotel_goods_sku-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.hotelGoodsSkuService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "hotel_goods_sku-通过id查询")
	@ApiOperation(value="hotel_goods_sku-通过id查询", notes="hotel_goods_sku-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<HotelGoodsSku> queryById(@RequestParam(name="id",required=true) String id) {
		HotelGoodsSku hotelGoodsSku = hotelGoodsSkuService.getById(id);
		if(hotelGoodsSku==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(hotelGoodsSku);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param hotelGoodsSku
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HotelGoodsSku hotelGoodsSku) {
        return super.exportXls(request, hotelGoodsSku, HotelGoodsSku.class, "hotel_goods_sku");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, HotelGoodsSku.class);
    }

	 @GetMapping(value = "/copy")
	 public Result<?> copyGoods(@RequestParam(name="id",required=true) String id){
		 HotelGoodsSku hotelGoodsSku = hotelGoodsSkuService.getById(id);

		 HotelGoodsSku hotelGoodsSku2 = new HotelGoodsSku();
		 BeanUtils.copyProperties(hotelGoodsSku,hotelGoodsSku2);
		 hotelGoodsSku2.setId(IdWorker.getIdStr());
		 hotelGoodsSku2.setColour(hotelGoodsSku.getColour()+"-副本");
		 hotelGoodsSku2.setTitle(hotelGoodsSku.getTitle()+"-副本");
		 hotelGoodsSku2.setCreateTime(new Date());
		 hotelGoodsSkuService.save(hotelGoodsSku2);

		 return Result.OK();
	 }

}
